=============
API reference
=============

The API reference is organized in a python package structure and a CLI-API.

.. toctree::
   :maxdepth: 1

   Python package <weatherDB>
   CLI <cli>

.. autosummary::
   :toctree: _autosummary
   :recursive: